==> hpecp-0.0.3.tar.gz: hpecp-0.0.3/hpecp/logger.py <==
# (C) Copyright [2020] Hewlett Packard Enterprise Development LP
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.

import logging
import os


class Logger(object):

    logger = None

    @classmethod
    def get_logger(cls):

        format = (
            "%(asctime)s - %(filename)s "
            "- %(name)s - %(levelname)s - %(message)s"
        )
        logging.basicConfig(format=format)
        Logger.logger = logging.getLogger("HPECP_CLI")
        Logger.logger.setLevel(os.getenv("LOG_LEVEL", logging.INFO))
        return Logger.logger

==> hpecp-0.10.5.tar.gz: hpecp-0.10.5/hpecp/logger.py <==
# (C) Copyright [2020] Hewlett Packard Enterprise Development LP
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.

import logging
import logging.config
import os


class Logger(object):

    logger = None

    @classmethod
    def get_logger(cls):

        if "HPECP_LOG_CONFIG_FILE" in os.environ:
            logging.config.fileConfig(os.getenv("HPECP_LOG_CONFIG_FILE"))
            Logger.logger = logging.getLogger("HPECP_CLI")
        else:
            format = (
                "%(asctime)s - %(filename)s "
                "- %(name)s - %(levelname)s - %(message)s"
            )
            logging.basicConfig(format=format)
            Logger.logger = logging.getLogger("HPECP_CLI")
            Logger.logger.setLevel(os.getenv("LOG_LEVEL", logging.INFO))

        return Logger.logger
